**** Replication File

*** Persistent yet Ameliorable Shocks to Female Entrepreneurship: Experimental Evidence from Kenya 
*** Campos, Hernandez-de-Benito, Jamison, Safir, Zia


* Set Stata version
version 16.0
set varabbrev on

** Set directory

global maindir "C:\Users\wb558768\Downloads\rep-checks\176\Replication"

global output "$maindir/output"
sysdir set PLUS "${maindir}/ado"





***********************************************************************************************************************************************************
********* REGRESSION DATASET ************************
***********************************************************************************************************************************************************


use "$maindir\Data\kyeop_gender_clean.dta", clear 


/****Business Outcomes*****/

/*Ownership*/
bysort survey_id: egen had_business=sum((baseline==1)*(sector_bl!=21))
label variable had_business "Had business at baseline"

foreach x in has_business numb_business {
	gen `x'_hadb=`x' if had_business==1 
	gen `x'_nohadb=`x' if had_business==0
	
} 
foreach x of varlist has_business* {
    label variable `x' "Owns Business"
}
foreach x of varlist numb_business* {
    label variable `x' "\# Business"
}


/*Performance*/



bysort survey_id: egen nbus_base=sum(numb_business*(baseline==1)) /*Number of business at baseline*/
label variable nbus_base "Number business at baseline"

gen sales1_w5_hadb_all=sales_w5
replace sales1_w5_hadb_all=0 if has_business==0 & post_covid2==1 
 
gen profit2_w5_hadb_all=profit_w5
replace profit2_w5_hadb_all=0 if has_business==0 & post_covid2==1 

label variable sales1_w5_hadb_all "All"
label variable sales1_w5 "Surviving"

label variable profit2_w5_hadb_all "All"
label variable profit2_w5 "Surviving"

 
/****Income and Work Outcomes*****/
gen dnumber_sources_income=(number_sources_income>0) if number_sources_income!=.
label variable  dnumber_sources_income "Has income source"

gen gap=spouse_income-income_primact_zb
label variable gap "Spousal income gap"
winsor2 gap, cuts(5 95) suffix(_w5)



egen number_work_act=rowtotal(work_as*)
label variable number_work_act "Number working activities"


/****Time Use*****/
gen hours_total_children=hours_help+hours_care+hours_play 
label variable hours_total_children "Childcare"

/****Vignettes*****/

gen avg_vignettes_cont=(vignette_control_cont+vignette_voice_cont+vignette_depend_cont)/3
label variable avg_vignettes_cont "Vignettes (average)"
 
 
save "$maindir/Data/GenderCovid_reg_dataset.dta", replace 
 





***********************************************************************************************************************************************************
********* MAIN FIGURES AND TABLES ************************
***********************************************************************************************************************************************************

*********************************************************************************************
********* Figure 1: Timeline of interventions and follow-up surveys  ************************
*********************************************************************************************


clear 
set obs 23
gen date=mofd(mdy(2,1,2020)) in  1
replace date=date[_n-1]+1 if _n>1 

gen id=_n 

format date %tmMonth-yy

gen c=100
gen zero=0 

gen follow_up1=95 if _n>=9 & _n<=11
gen follow_up2=95 if _n>=21 & _n<=23

gen bds1=50 if _n>=1 & _n<=14 
gen bds2=30 if _n>=6 & _n<=11 


twoway (scatter c id   , mcolor(none) ) ///
(rarea follow_up1 zero id , color(red%50) ) ///
(rarea follow_up2 zero id , color(green%50) ) ///
(line bds1 id ) ///
(line bds2 id ) ///
, ///
xlabel(1 "Baseline: Feb-20" 2 "Mar-20" 6 "Jul-2020"  9 "Oct-20" 11 "Dec-20" 14 "Mar-21" 21 "Oct-21" 23 "Dec-21", angle(60) labsize(vsmall)) ///
ylabel(none)  xscale(range(1 .)) ytitle(" ") xtitle(" ") ///
xline(2,  lcolor(black)) text(100.9 2 "Cl 1: Grant 1 ", place(e) size(vsmall) ) ///
xline(6, lcolor(black)) text(100.9 6 "Cl 1: Grant 2 ", place(e) size(vsmall))   ///
xline(10, lcolor(black)) text(100.9 10 "Cl 2 and 3: Grant 1 ", place(e) size(vsmall) ) ///
xline(14,  lcolor(black)) text(100.9 14 "Cl 2 and 3: Grant 2 ", place(e) size(vsmall))   ///
legend( order(2 "First follow-up survey" 3 "Second follow-up survey" 4 "Cl 1: BDS" 5 "Cl 2 and 3: BDS") size(vsmall)) ///
graphregion(color(white)) plotregion(color(white))  

graph export "$output/F_Figure1.png", as(png) replace


*********************************************************************************************
********* Table 1: Baseline Descriptive Statistics and Balance ************************
*********************************************************************************************


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear

keep if baseline==1

gen sales1_w5_hadb_all_prim=sales_w5  if nbus_base==1
gen profit2_w5_hadb_all_prim=profit_w5 if nbus_base==1 

summ sales_w5 profit_w5 

gen pc_bds=(grants_only==0 & grants_and_bds==0)


label variable sales1_w5_hadb_all_prim "Monthly sales (W.5%)"
label variable profit2_w5_hadb_all_prim "Monthly profits (W.5%)"

local indvars "age secondary hhsize total_children num_ch_under4_inhh ever_child age_first_child"
local econvars "number_sources_income income_primact_kb "
local busvars  "has_business sales1_w5_hadb_all_prim profit2_w5_hadb_all_prim"
local timeuse "hours_work  hours_dom hours_total_children"

 
tempfile all 
save `all'

gen variable=""

foreach x in mu_1f sd_1f mu_2f sd_2f mu_3f sd_3f bf sef mu_1m sd_1m mu_2m sd_2m mu_3m sd_3m bm sem {
	capture drop `x'
		gen `x'=.
}


local j=1

foreach var in `indvars' `econvars' `busvars' `timeuse' {
		local varlabel : variable label `var'
		replace variable= "`varlabel'" in `j'
		
		summ `var' if female==1 & grants_only==1
		replace mu_1f=r(mean) in `j'
		replace sd_1f=r(sd) in `j'
		 
		
		
		summ `var' if female==1 & grants_and_bds==1 
		replace mu_2f=r(mean) in `j'
		replace sd_2f=r(sd) in `j'
		 
		
        summ `var' if female==1 & pc_bds==1 
		replace mu_3f=r(mean) in `j'
		replace sd_3f=r(sd) in `j'
		 
		
        
		reg `var' pc_bds if female==1, vce(robust)
		replace bf=_b[pc_bds] in `j'
		replace sef=_se[pc_bds] in `j'
		
		summ `var' if female==0 & grants_only==1
		replace mu_1m=r(mean) in `j'
		replace sd_1m=r(sd) in `j'
		
		
		summ `var' if female==0 & grants_and_bds==1 
		replace mu_2m=r(mean) in `j'
		replace sd_2m=r(sd) in `j'
		 
        
		summ `var' if female==0 & pc_bds==1 
		replace mu_3m=r(mean) in `j'
		replace sd_3m=r(sd) in `j'
	 
        
		reg `var' pc_bds if female==0, vce(robust)
		replace bm=_b[pc_bds] in `j'
		replace sem=_se[pc_bds] in `j'
		     
        
		local j=`j'+1
}

keep variable mu_1* sd_1*   mu_2* sd_2*  mu_3* sd_3*  bf sef bm sem 
keep if variable!=""

	gen id=_n

	tempfile dall
	save `dall'

	keep variable id

	append using `dall'

	gsort id -mu_1f
	


    gen tf=bf/sef
	gen tm=bm/sem
	
   
	tostring mu* sd* bf bm sem sef , format(%12.2fc) replace force
	 
	forvalues i=1/3 {
	    foreach x in m f {
			replace mu_`i'`x'="["+sd_`i'`x'[_n-1]+"]" if mu_`i'`x'=="."
			
	}
	}
	
 
	
	
    foreach x in m f {
		replace b`x'="("+se`x'[_n-1]+")" if b`x'=="."
		replace b`x'=b`x'+"*"   if abs(t`x')>=invnormal(0.95) & abs(t`x')<invnormal(0.975)
		replace b`x'=b`x'+"**"   if abs(t`x')>=invnormal(0.975) & abs(t`x')<invnormal(0.995)
		replace b`x'=b`x'+"***"   if abs(t`x')>=invnormal(0.995) 	& t`x'!=.
		}
	
    keep variable mu_1*  mu_2*  mu_3* bf bm
	replace variable="" if regexm(mu_1f,"\[")


gen id=_n	

sort id 

label variable mu_1f "Grants"
label variable mu_2f "Grants+BDS"
label variable mu_3f "C/BDS only"


label variable mu_1m "Grants"
label variable mu_2m "Grants+BDS"
label variable mu_3m "C/BDS only"

 
label variable bf "T-C/BDS only"
label variable bm "T-C/BDS only"


tempfile balance
save `balance'

/*All: male vs female*/

use `all', clear 

gen variable=""

foreach x in mu_1 sd_1 N_1 mu_2 sd_2 N_2  b se  {
	capture drop `x'
		gen `x'=.
}


local j=1

foreach var in `indvars' `econvars' `busvars' `timeuse' {
		local varlabel : variable label `var'
		replace variable= "`varlabel'" in `j'
		
		summ `var' if female==1
		replace mu_1=r(mean) in `j'
		replace sd_1=r(sd) in `j'
		 
		
		summ `var' if female==0
		replace mu_2=r(mean) in `j'
		replace sd_2=r(sd) in `j'
		 
        
        
		reg `var' female, vce(robust)
		replace b=_b[female] in `j'
		replace se=_se[female] in `j'
        
        
		local j=`j'+1
}

keep variable mu_1 sd_1   mu_2 sd_2   b se
keep if variable!=""

	gen id=_n

	tempfile dall
	save `dall'

	keep variable id

	append using `dall'

	gsort id -mu_1

    gen t=b/se
    

	tostring mu* sd* b se , format(%12.2fc) replace force
 
	forvalues i=1/2 {
			replace mu_`i'="["+sd_`i'[_n-1]+"]" if mu_`i'=="."
			 
	}
	
    
    replace b="("+se[_n-1]+")" if b=="."
    replace b=b+"*"   if abs(t)>=invnormal(0.95) & abs(t)<invnormal(0.975)
    replace b=b+"**"   if abs(t)>=invnormal(0.975) & abs(t)<invnormal(0.995)
    replace b=b+"***"   if abs(t)>=invnormal(0.995) 	& t!=.
    
    keep variable mu_1  mu_2  b
	replace variable="" if regexm(mu_1,"\[")


gen id=_n	

sort id 

label variable mu_1 "Female"
label variable mu_2 "Male"
label variable b "Diff."

merge 1:1 id variable using `balance'

set obs `=_N+4'
replace variable="Socio-economic" in `=_N-3'
replace id=0 in `=_N-3'
replace variable="Primary Business" in  `=_N-2'
replace id=20.5 in  `=_N-2'
replace variable="Time Use" in  `=_N-1'
replace id=24.5 in  `=_N-1'
replace variable="Observations" in  `=_N'
replace id=30.5 in  `=_N'

gsort id -variable 


replace mu_1="937" in  `=_N'
replace mu_2="778" in  `=_N'

replace mu_1f="239" in  `=_N'
replace mu_2f="286" in  `=_N'
replace mu_3f="412" in  `=_N'

replace mu_1m="189" in  `=_N'
replace mu_2m="253" in  `=_N'
replace mu_3m="336" in  `=_N'

keep variable mu_1 mu_2 b mu_1f mu_2f mu_3f bf mu_1m mu_2m mu_3m bm 
order variable mu_1 mu_2 b mu_1f mu_2f mu_3f bf mu_1m mu_2m mu_3m bm 

	export excel using "$output/T_Table1.xls", replace firstrow(varlabel)



*******************************************************************
**** Table 2: Impact of COVID-19 on Business Ownership
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear
 
 
*Define variables
local tabname				Table2

local outcomes	     		has_business has_business_hadb has_business_nohadb  
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2   

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2       
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		if inlist("`var'","has_business" ) {
		
		estadd scalar pct0=_b[c.post_covid#c.female]/(meanb_0-meanb_1)
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		}
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}


estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'   "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1 k peq , fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)"  )) ///
		replace lines  legend  depvar label  nonotes  noomitted nomtitle ///
	keep( c.post_covid#c.female c.post_covid2#c.female     ) ///
	order (c.post_covid#c.female c.post_covid2#c.female    ) 
	
	
	
 *******************************************************************
**** Table 3: Impact of COVID-19 on Business Monthly Sales and Profits (W. 5%)
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 


drop if post_covid==1 
keep if nbus_base==1
 

*Define variables
local tabname				Table3

local outcomes	     		sales1_w5_hadb_all   profit2_w5_hadb_all
							
local controls1 		  	post_covid2 c.post_covid2#c.female           i.County#c.post_covid2  

local controls2 		  	`controls1' i.sector_bl#c.post_covid2 
          
 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1

drop if has_business==1 & baseline==1 
 
bysort survey_id: egen c=count(survey_id)
keep if c==2 

 
gen sales1_w5_nohadb_cre=0 if has_business==0 & post_covid2==0 
replace sales1_w5_nohadb_cre=sales_w5 if post_covid2==1 

 
gen profit2_w5_nohadb_cre=0 if has_business==0 & post_covid2==0  
replace profit2_w5_nohadb_cre=profit_w5 if post_covid2==1  


foreach x in sales1_w5_nohadb_cre  profit2_w5_nohadb_cre {
	gen `x'_1b=`x'
	replace `x'_1b=. if post_covid2==1 & numb_business>1
}

foreach x of varlist sales1* {
	label variable `x' "Sales"
}
foreach x of varlist profit2* {
	label variable `x' "Profits"
}

keep if post_covid2==1

*Define variables

local outcomes	     		 sales1_w5_nohadb_cre profit2_w5_nohadb_cre   
							
local controls1 		  	post_covid2 c.post_covid2#c.female           i.County 
         
 
*Estimation 

foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reg `var' `controls`j'' ,  vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}

estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)' "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0  meana_0 k meanb_1  meana_1 , fmt(%9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male"   "Covid 2021 mean, male"  "\hline" "Pre-Covid mean, female"   "Covid 2021 mean, female" )) ///
		replace lines compress legend  depvar label   nonotes nonumbers  noomitted nomtitles ///
	keep( c.post_covid2#c.female     ) ///
	order ( c.post_covid2#c.female    ) 	


********************************************************************
**** Table 4: Impact of COVID-19 on Time Use 
*******************************************************************

 
use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

 

*Define variables
local tabname				Table4

local outcomes	     		hours_total_children  hours_work  hours_dom hours_soc  hours_sleep hours_eat     
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2   

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2       
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=2/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
			test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		estadd scalar pct0=_b[c.post_covid#c.female]/(meanb_0-meanb_1)
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}

estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'   "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1 k peq , fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)" )) ///
		replace lines compress legend  depvar label   nonotes  noomitted  ///
	keep( c.post_covid#c.female c.post_covid2#c.female     ) ///
	order ( c.post_covid#c.female c.post_covid2#c.female    ) 	



*******************************************************************
**** Table 5: Gendered Differences in Business Changes in Response to Covid-19
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 


drop if post_covid==0 & post_covid2==0 

foreach x of varlist  activ_* {
     
    bysort survey_id: egen s`x'_r1=sum(`x'*(post_covid==1)), missing
	bysort survey_id: egen s`x'_r2=sum(`x'*(post_covid2==1)), missing
	
	gen cum_`x'=s`x'_r1 if post_covid==1
	replace cum_`x'=1 if post_covid2==1 & ( s`x'_r1==1 | s`x'_r2==1) 
	replace cum_`x'=0 if post_covid2==1 & ( s`x'_r1==0 & s`x'_r2==0) 
	replace cum_`x'=0 if post_covid2==1 & ( s`x'_r1==0 & s`x'_r2==.)
	replace cum_`x'=0 if post_covid2==1 & ( s`x'_r1==. & s`x'_r2==0)	
}
 

label variable cum_activ_1 "Sell/transfer"
label variable cum_activ_2 "Online/remote"
label variable cum_activ_3 "Changed products/services"
label variable cum_activ_4 "Changed location"
label variable cum_activ_5 "Govt. help"
label variable cum_activ_6 "Formal/informal loan"

label variable secondary "Secondary"
 

 estimates drop _all 
foreach x of varlist cum_activ* {
    
	reg `x' female age secondary i.County i.sector_bl grants_only grants_and_bds if post_covid2==1, vce(cluster survey_id)
	forvalues f=0/1 {
			sum `x' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	}
	estimates store m`x'
}

local tabname "Table5"
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate("County FE=*County*" "Business sector FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(    N k meana_0 meana_1, fmt(%9.0gc %9.2f %9.2f %9.2f   ) labels(   "Observations" "\hline" "Outcome mean, male" "Outcome mean, female" )) ///
		replace lines compress legend  depvar label   nonotes  noomitted  ///
	keep( female age secondary  grants_only grants_and_bds    ) ///
	order ( female age secondary) 	

*******************************************************************
**** Table 6: Impact of COVID-19 on Income Variables
*******************************************************************


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1  
 

*Define variables
local tabname				Table6

local outcomes	     		dnumber_sources_income number_sources_income income_primact_zb income_primact_zb_w5 income_primact_kb income_primact_kb_w5   gap gap_w5


 local controls1 	    	post_covid2 c.post_covid2#c.female          i.County#c.post_covid2  i.sector_bl#c.post_covid2
 		
 

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		 
		
	 
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
 


estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)' "Survey FE=post_covid2" "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
					stats(  N k meanb_0  meana_0 k meanb_1  meana_1 , fmt(%9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male"   "Covid 2021 mean, male"  "\hline" "Pre-Covid mean, female"   "Covid 2021 mean, female" )) ///
		replace lines compress legend  depvar label   nonotes nonumbers noomitted nomtitles  ///
	keep(  c.post_covid2#c.female      ) ///
	order (   c.post_covid2#c.female    ) 	 

*******************************************************************
**** Table 7: Impact of COVID-19 on Intra-Household Dynamics
*******************************************************************
use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 
drop if baseline==1 

foreach x of varlist avg_vignettes_cont   vignette_control_cont vignette_voice_cont vignette_depend_cont {

drop if `x'==.
}


bysort survey_id: egen c=count(2)
keep if c==2 

summ  avg_vignettes_cont
replace avg_vignettes_cont=(avg_vignettes_cont -r(mean))/r(sd)




*Define variables
local tabname				Table7

local outcomes	     		avg_vignettes_cont   vignette_control_cont vignette_voice_cont vignette_depend_cont

local controls1 c.post_covid#c.female   	c.post_covid2 c.post_covid2#c.female   i.County#c.post_covid    i.County#c.post_covid2  i.sector_bl#c.post_covid i.sector_bl#c.post_covid2  c.negative_framing#c.post_covid c.negative_framing#c.post_covid2  i.rand_vig#c.post_covid i.rand_vig#c.post_covid2,   vce(cluster survey_id)

 local controls2  c.post_covid#c.female   	post_covid2 c.post_covid2#c.female   c.post_covid#c.hours_total_children c.post_covid#c.female#c.hours_total_children c.post_covid2#c.hours_total_children c.post_covid2#c.female#c.hours_total_children  i.County#c.post_covid    i.County#c.post_covid2 i.County#c.post_covid#c.hours_total_children    i.County#c.post_covid2#c.hours_total_children i.sector_bl#c.post_covid i.sector_bl#c.post_covid2 i.sector_bl#c.post_covid#c.hours_total_children i.sector_bl#c.post_covid2#c.hours_total_children    c.negative_framing#c.post_covid c.negative_framing#c.post_covid2  i.rand_vig#c.post_covid i.rand_vig#c.post_covid2,   vce(cluster survey_id)

							

*Estimation 
local i = 1

est drop _all
foreach var in `outcomes'  {
forvalues j=1/1{
 

	

reg `var'  `controls`j''


forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
		}
		
 
	test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
		
}
}

esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate("County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  stats(N k mean_0 meana_0 k mean_1 meana_1 k peq   , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Covid 2020 mean, female" "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)")) depvar label   nonotes  noomitted nomtitles ///
	drop(*negative* *rand*) ///
	order(c.post_covid#c.female   c.post_covid2#c.female  )  



*******************************************************************
****Table 8: Grants and BDS Treatment Effects during COVID: Business Outcomes

*******************************************************************


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 


*Define variables
local tabname				Table8
 
local outcomes has_business  has_business_hadb has_business_nohadb 

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
}
  
  
 
use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 
keep if nbus_base==1

  
*Define variables
 

local outcomes	     		sales1_w5_hadb_all profit2_w5_hadb_all 
							

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female
          
 
*Estimation 
 
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

} 
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_onlyf grants_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "   "Grant and BDS effect for females" " " "\hline" "Control+BDS only mean, male" "Control+BDS only mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
				indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep(  c.post_covid2#c.grants_only  c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_only#c.female        c.post_covid2#c.grants_and_bds#c.female  ) ///
	order ( c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female      c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female      )  

	
*******************************************************************
****Table 9: Grants and BDS Treatment Effects during COVID: Income Variables
*******************************************************************


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 
 

*Define variables
local tabname				Table9

local outcomes	     		dnumber_sources_income number_sources_income income_primact_zb income_primact_zb_w5 income_primact_kb income_primact_kb_w5   gap gap_w5
 

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
  
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_onlyf grants_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "   "Grant and BDS effect for females" " " "\hline" "Control+BDS only mean, male" "Control+BDS only mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
								indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep(  c.post_covid2#c.grants_only  c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_only#c.female        c.post_covid2#c.grants_and_bds#c.female  ) ///
	order ( c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female      c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female      ) 	 
	
*******************************************************************
**** Table 10: Grants and BDS Treatment Effects during COVID: Time Use
*******************************************************************



use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 


 
*Define variables
local tabname				Table10

local outcomes	     		hours_total_children  hours_work  hours_dom hours_soc  hours_sleep hours_eat     
 

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
  
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
			stats(N k grants_onlyf grants_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "   "Grant and BDS effect for females" " " "\hline" "Control+BDS only mean, male" "Control+BDS only mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
								indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted  ///
	keep(  c.post_covid2#c.grants_only  c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_only#c.female        c.post_covid2#c.grants_and_bds#c.female  ) ///
	order ( c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female      c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female      )  
	

*******************************************************************
****Table 11: Grants and BDS Treatment Effects during COVID: Subjective Wellbeing
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

keep if post_covid2==1 
 					
summ  avg_vignettes_cont
replace avg_vignettes_cont=(avg_vignettes_cont -r(mean))/r(sd)


replace sect5_wellbeinggc2=sect5_wellbeinggc2*-1					

*Define variables
local tabname				Table11
 
local outcomes sect5_ladder_stepgc2 sect5_life_in5yearsgc2 sect5_wellbeinggc2  	sect5_workbalgc2 avg_vignettes_cont 

local controls1		  	 female i.County i.sector_bl grants_only c.grants_only#c.female       grants_and_bds  c.grants_and_bds#c.female
 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reg `var' `controls`j'' , vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom `t' + c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test   grants_only=grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		test ///
		 grants_only+  c.grants_only#c.female = ///
		 c.grants_and_bds+  grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
  
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'  "County FE=*County*" "Baseline business sector =*sector_bl*"  , label("\checkmark" "")  ) ///
			stats(N k grants_onlyf grants_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "  "Grant and BDS effect for females" " " "\hline" "Control+BDS only mean, male" "Control +BDS only mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles nonumbers ///
	keep( female grants_only     grants_and_bds  c.grants_only#c.female         c.grants_and_bds#c.female  ) ///
	order ( female  grants_only    c.grants_only#c.female    grants_and_bds  c.grants_and_bds#c.female  )  
 


******************************************************************************************************************************************************************************************
********* APPENDIX ************************
******************************************************************************************************************************************************************************************

***********************************************************

**** TABLE C1 
***********************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 

keep if baseline==1

drop if sector_bl==21

tab sector_bl, gen(sectorind)
 
 
gen variable=""

foreach x in mu_1 sd_1 N_1 mu_2 sd_2 N_2  b se  {
	capture drop `x'
		gen `x'=.
}


local j=1

foreach var of varlist sectorind* {
		local varlabel : variable label `var'
		replace variable= "`varlabel'" in `j'
		
		summ `var' if female==1
		replace mu_1=r(mean) in `j'
		replace sd_1=r(sd) in `j'
		replace N_1=r(N) in `j'
		
		summ `var' if female==0
		replace mu_2=r(mean) in `j'
		replace sd_2=r(sd) in `j'
		replace N_2=r(N) in `j'
        
        
		reg `var' female, vce(robust)
		replace b=_b[female] in `j'
		replace se=_se[female] in `j'
        
        
		local j=`j'+1
}

keep variable mu_1 sd_1 N_1 mu_2 sd_2 N_2  b se
keep if variable!=""

	gen id=_n

	tempfile dall
	save `dall'

	keep variable id

	append using `dall'

	gsort id -mu_1

    gen t=b/se
    

	tostring mu* sd* b se , format(%12.2fc) replace force
	tostring N* , format(%12.0gc) replace force
	
	forvalues i=1/2 {
			replace mu_`i'="["+sd_`i'[_n-1]+"]" if mu_`i'=="."
			replace N_`i'="" if N_`i'=="."
	}
	
    
    replace b="("+se[_n-1]+")" if b=="."
    replace b=b+"*"   if abs(t)>=invnormal(0.95) & abs(t)<invnormal(0.975)
    replace b=b+"**"   if abs(t)>=invnormal(0.975) & abs(t)<invnormal(0.995)
    replace b=b+"***"   if abs(t)>=invnormal(0.995) 	& t!=.
    
    keep variable mu_1 N_1 mu_2 N_2 b
	replace variable="" if N_1==""

gen id=_n	

sort id 

label variable mu_1 "Mean and SD"
label variable mu_2 "Mean and SD"
label variable N_1 "Obs."
label variable N_2 "Obs."
label variable b "[Female - Male]"

replace variable=substr(variable,12,100)

keep variable mu_1 N_1 mu_2  N_2 b
order variable mu_1 N_1 mu_2  N_2 b


export excel using "$output/T_TableC1.xls", replace firstrow(varlabel)




*******************************************************************
**** TABLE C2 
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 
*Define variables
local tabname				TableC2

local outcomes	     		numb_business numb_business_hadb   numb_business_nohadb   
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2   

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2       
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		if inlist("`var'","has_business" ) {
		
		estadd scalar pct0=_b[c.post_covid#c.female]/(meanb_0-meanb_1)
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		}
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
 
 

estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'   "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1 k peq , fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)"  )) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitle ///
	keep( c.post_covid#c.female c.post_covid2#c.female     ) ///
	order (c.post_covid#c.female c.post_covid2#c.female    ) 
	
	

*******************************************************************
**** TABLE C3
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 
drop if grants_only==1 | grants_and_bds==1  
 
*Define variables
local tabname				TableC3
local outcomes	     		has_business has_business_hadb has_business_nohadb  
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2   

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2       
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		if inlist("`var'","has_business" ) {
		
		estadd scalar pct0=_b[c.post_covid#c.female]/(meanb_0-meanb_1)
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		}
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
 
}
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt"  	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'   "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1 k peq , fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)"  )) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitle ///
	keep( c.post_covid#c.female c.post_covid2#c.female     ) ///
	order (c.post_covid#c.female c.post_covid2#c.female    ) 	 
	


*******************************************************************
**** TABLE C4
*******************************************************************


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 

keep if nbus_base==1

 
*Define variables
local tabname				TableC4

local outcomes	     		 sales_w5 profit_w5   
							
local controls1 		  	post_covid2 c.post_covid2#c.female           i.County#c.post_covid2  

local controls2 		  	`controls1' i.sector_bl#c.post_covid2 
          
 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}

}	

 
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)' "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0  meana_0 k meanb_1  meana_1 , fmt(%9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male"   "Covid 2021 mean, male"  "\hline" "Pre-Covid mean, female"   "Covid 2021 mean, female" )) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep( c.post_covid2#c.female     ) ///
	order ( c.post_covid2#c.female    ) 
	
	
*******************************************************************
**** TABLE C5
*******************************************************************


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 


drop if grants_only==1 | grants_and_bds==1  


drop if post_covid==1 
 
keep if nbus_base==1
 
 

*Define variables
local tabname				TableC5

local outcomes	     		sales1_w5_hadb_all   profit2_w5_hadb_all
							
local controls1 		  	post_covid2 c.post_covid2#c.female           i.County#c.post_covid2  

local controls2 		  	`controls1' i.sector_bl#c.post_covid2 
          
 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
drop if grants_only==1 | grants_and_bds==1  


drop if post_covid==1

drop if has_business==1 & baseline==1 
 
bysort survey_id: egen c=count(survey_id)
keep if c==2 
gen sales1_w5_nohadb_cre=0 if has_business==0 & post_covid2==0 
replace sales1_w5_nohadb_cre=sales_w5 if post_covid2==1 

 
gen profit2_w5_nohadb_cre=0 if has_business==0 & post_covid2==0  
replace profit2_w5_nohadb_cre=profit_w5 if post_covid2==1  


foreach x in sales1_w5_nohadb_cre  profit2_w5_nohadb_cre {
	gen `x'_1b=`x'
	replace `x'_1b=. if post_covid2==1 & numb_business>1
}
  

keep if post_covid2==1

*Define variables

local outcomes	     		 sales1_w5_nohadb_cre profit2_w5_nohadb_cre   
							
local controls1 		  	post_covid2 c.post_covid2#c.female           i.County 
         
 
*Estimation 

foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reg `var' `controls`j'' ,  vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}


estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)' "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0  meana_0 k meanb_1  meana_1 , fmt(%9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male"   "Covid 2021 mean, male"  "\hline" "Pre-Covid mean, female"   "Covid 2021 mean, female" )) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep( c.post_covid2#c.female     ) ///
	order ( c.post_covid2#c.female    ) 
	
	
*******************************************************************
**** TABLE C6 
*******************************************************************


use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 
gen grouped_sector=.
local j=1
foreach i in   3 9   18 {
	replace grouped_sector=`j' if sector_bl==`i'
	local j=`j'+1
}

replace grouped_sector=4 if grouped_sector==. & sector_bl!=21 

label define sector 1 "Agriculture, forestry and fishing" 2 "Human health and social work activities" 3  "Wholesale and retail trade,repair of motor vehicles" 4 "Other"

label values grouped_sector sector


tab grouped_sector, gen(secind)

foreach x of varlist secind* {
gen p1_female_`x'= post_covid*female*`x'
gen p2_female_`x'= post_covid2*female*`x'

}

label variable p1_female_secind1 "Covid 2020 $\times$ Female $\times$ Agriculture, forestry and fishing"
label variable p1_female_secind2 "Covid 2020 $\times$ Female $\times$ Human health and social work activities"
label variable p1_female_secind3 "Covid 2020 $\times$ Female $\times$ Wholesale and retail trade,repair of motor vehicles"
label variable p1_female_secind4 "Covid 2020 $\times$ Female $\times$ Other"


label variable p2_female_secind1 "Covid 2021 $\times$ Female $\times$ Agriculture, forestry and fishing"
label variable p2_female_secind2 "Covid 2021 $\times$ Female $\times$ Human health and social work activities"
label variable p2_female_secind3 "Covid 2021 $\times$ Female $\times$ Wholesale and retail trade,repair of motor vehicles"
label variable p2_female_secind4 "Covid 2021 $\times$ Female $\times$ Other"

*Define variables
local tabname				TableC6 

local outcomes	     		has_business 
							
local controls1 		post_covid c.post_covid#i.grouped_sector   p1_female_secind1 p1_female_secind2 p1_female_secind3 p1_female_secind4	c.post_covid2#i.grouped_sector  c.post_covid2#i.grouped_sector p2_female_secind1 p2_female_secind2 p2_female_secind3 p2_female_secind4      i.County#c.post_covid    i.County#c.post_covid2 i.County#c.post_covid#i.grouped_sector    i.County#c.post_covid2#i.grouped_sector   
    
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		 
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
 
 
 

*Sales+profits+new business in one table*/
 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

gen grouped_sector=.
local j=1
foreach x in   3 9   18 {
	replace grouped_sector=`j' if sector_bl==`x'
	local j=`j'+1
}

replace grouped_sector=4 if grouped_sector==. & sector_bl!=21 

label define sector 1 "Agriculture, forestry and fishing" 2 "Human health and social work activities" 3  "Wholesale and retail trade,repair of motor vehicles" 4 "Other"

label values grouped_sector sector
drop if post_covid==1 

 
keep if nbus_base==1
 
 

tab grouped_sector, gen(secind)

foreach x of varlist secind* {
gen p1_female_`x'= post_covid*female*`x'
gen p2_female_`x'= post_covid2*female*`x'

}
label variable p1_female_secind1 "Covid 2020 $\times$ Female $\times$ Agriculture, forestry and fishing"
label variable p1_female_secind2 "Covid 2020 $\times$ Female $\times$ Human health and social work activities"
label variable p1_female_secind3 "Covid 2020 $\times$ Female $\times$ Wholesale and retail trade"
label variable p1_female_secind4 "Covid 2020 $\times$ Female $\times$ Other"


label variable p2_female_secind1 "Covid 2021 $\times$ Female $\times$ Agriculture, forestry and fishing"
label variable p2_female_secind2 "Covid 2021 $\times$ Female $\times$ Human health and social work activities"
label variable p2_female_secind3 "Covid 2021 $\times$ Female $\times$ Wholesale and retail trade"
label variable p2_female_secind4 "Covid 2021 $\times$ Female $\times$ Other"

*Define variables
 

local outcomes	     		sales1_w5_hadb_all   profit2_w5_hadb_all
							
local controls1 		  	post_covid2 c.post_covid2#i.grouped_sector p2_female_secind1 p2_female_secind2 p2_female_secind3 p2_female_secind4     i.County#c.post_covid2  i.County#c.post_covid2#i.grouped_sector   
  
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
	
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		 
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}

 
 
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)' "County*Survey FE=*County*" "Baseline business sector*Survey FE=*grouped_sector*"  , label("\checkmark" "")  ) keep( p1_female_secind1 p1_female_secind2 p1_female_secind3 p1_female_secind4   p2_female_secind1 p2_female_secind2 p2_female_secind3 p2_female_secind4  )  ///
				stats(  N k meanb_0  meana_0 k meanb_1  meana_1  , fmt(%9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male"   "Covid 2021 mean, male"  "\hline" "Pre-Covid mean, female"   "Covid 2021 mean, female"  )) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles  
		
		
		

*******************************************************************
**** Table C7: Impact of COVID-19 on Time Use (If worked before)
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

bysort survey_id: egen wb=sum(hours_work*(post_covid==0)*(post_covid2==0))
keep if wb>0 

 

*Define variables
local tabname				TableC7

local outcomes	     		hours_total_children  hours_work  hours_dom hours_soc  hours_sleep hours_eat     
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2  

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2        
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=2/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			
			estadd scalar meanb_`f' = r(mean)
			
			
		}
			test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		estadd scalar pct0=_b[c.post_covid#c.female]/(meanb_0-meanb_1)
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}

estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'   "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1 k peq, fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)" )) ///
		replace lines compress legend  depvar label   nonotes  noomitted  ///
	keep( c.post_covid#c.female c.post_covid2#c.female     ) ///
	order ( c.post_covid#c.female c.post_covid2#c.female    ) 	

*******************************************************************
**** TABLE C8 
*******************************************************************	

 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

 drop if grants_only==1 | grants_and_bds==1
 


*Define variables
local tabname				TableC8 

local outcomes	     		hours_total_children  hours_work  hours_dom hours_soc  hours_sleep hours_eat     
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2   

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2       
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=2/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
			test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		estadd scalar pct0=_b[c.post_covid#c.female]/(meanb_0-meanb_1)
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}

estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'   "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1 k peq, fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)" )) ///
		replace lines compress legend  depvar label   nonotes  noomitted  ///
	keep( c.post_covid#c.female c.post_covid2#c.female     ) ///
	order ( c.post_covid#c.female c.post_covid2#c.female    ) 	
		
		
*******************************************************************
**** TABLE C9 
*******************************************************************	

 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
bysort survey_id: egen wb=sum(hours_work*(post_covid==0)*(post_covid2==0))
keep if wb>0 
 drop if grants_only==1 | grants_and_bds==1
 


*Define variables
local tabname				TableC9

local outcomes	     		hours_total_children  hours_work  hours_dom hours_soc  hours_sleep hours_eat     
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2   

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2       
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=2/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			estadd scalar meanb_`f' = r(mean)
			
		}
			test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		estadd scalar pct0=_b[c.post_covid#c.female]/(meanb_0-meanb_1)
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}

estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'   "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1 k peq, fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female" "\hline" "$[$ Covid 2020 $\times$ female $]$ = \\ $[$ Covid 2021 $\times$ female $]$ (p-value)" )) ///
		replace lines compress legend  depvar label   nonotes  noomitted  ///
	keep( c.post_covid#c.female c.post_covid2#c.female     ) ///
	order ( c.post_covid#c.female c.post_covid2#c.female    ) 	
	
	
*******************************************************************
**** TABLE C10
*******************************************************************	
 

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 



tempfile all
save `all'

foreach x in sales1_w5_hadb_all profit2_w5_hadb_all  {
	replace `x'=. if  !(nbus_base==1 & post_covid==0)
}

replace sales1_w5=. if nbus_base!=1
replace profit2_w5=. if nbus_base!=1
replace profit2_w5=. if  post_covid==1

 
 
*Define variables
local tabname				TableC10

local outcomes	     		has_business     has_business_hadb has_business_nohadb sales1_w5_hadb_all   profit2_w5_hadb_all   
							
local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female         hours_total_children c.female#c.hours_total_children c.post_covid#c.hours_total_children c.post_covid#c.female#c.hours_total_children c.post_covid2#c.hours_total_children c.post_covid2#c.female#c.hours_total_children  i.County#c.post_covid    i.County#c.post_covid2 i.County#c.post_covid#c.hours_total_children    i.County#c.post_covid2#c.hours_total_children

local controls2 		`controls1' i.sector_bl#c.post_covid i.sector_bl#c.post_covid2 i.sector_bl#c.post_covid#c.hours_total_children i.sector_bl#c.post_covid2#c.hours_total_children      
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=2/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
 
 

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
drop if post_covid==1
drop if has_business==1 & baseline==1 
 
bysort survey_id: egen c=count(survey_id)
keep if c==2 

 
gen sales1_w5_nohadb_cre=0 if has_business==0 & post_covid2==0 
replace sales1_w5_nohadb_cre=sales_w5 if post_covid2==1 
 
gen profit2_w5_nohadb_cre=0 if has_business==0 & post_covid2==0  
replace profit2_w5_nohadb_cre=profit_w5 if post_covid2==1  


foreach x in sales1_w5_nohadb_cre  profit2_w5_nohadb_cre {
	gen `x'_1b=`x'
	replace `x'_1b=. if post_covid2==1 & numb_business>1
}

keep if post_covid2==1

*Define variables

local outcomes	     		 sales1_w5_nohadb_cre profit2_w5_nohadb_cre   
							
local controls2 		  	post_covid2 c.post_covid2#c.female      i.County   c.post_covid2#c.hours_total_children c.post_covid2#c.female#c.hours_total_children    i.County#c.hours_total_children


foreach var in `outcomes'  {
	
	forvalues j=2/2 {
		reghdfe `var' `controls`j'' ,   vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}


 
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
	indicate(`r(indicate_fe)' "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0 mean_0 meana_0 k meanb_1 mean_1 meana_1, fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male" "Covid 2020 mean, male" "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female" "Covid 2020 mean, female"  "Covid 2021 mean, female")) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitle ///
	keep(      c.post_covid#c.female  c.post_covid#c.hours_total_children   c.post_covid#c.female#c.hours_total_children   c.post_covid2#c.female  c.post_covid2#c.hours_total_children   c.post_covid2#c.female#c.hours_total_children ) ///
	order (   c.post_covid#c.female  c.post_covid#c.hours_total_children   c.post_covid#c.female#c.hours_total_children     c.post_covid2#c.female  c.post_covid2#c.hours_total_children   c.post_covid2#c.female#c.hours_total_children ) 	 
	
	
 *******************************************************************
**** TABLE C11
*******************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 
foreach x in sales1_w5_hadb_all profit2_w5_hadb_all  {
	replace `x'=. if  !(nbus_base==1 & post_covid==0)
}

replace sales1_w5=. if nbus_base!=1

replace profit2_w5=. if nbus_base!=1
replace profit2_w5=. if  post_covid==1

foreach x of varlist  activ_* {
    
    bysort survey_id: egen s`x'_r1=sum(`x'*(post_covid==1)), missing
	bysort survey_id: egen s`x'_r2=sum(`x'*(post_covid2==1)), missing
	
	gen cum_`x'=s`x'_r1 if post_covid==1
	replace cum_`x'=1 if post_covid2==1 & ( s`x'_r1==1 | s`x'_r2==1) 
	replace cum_`x'=0 if post_covid2==1 & ( s`x'_r1==0 & s`x'_r2==0) 
	replace cum_`x'=0 if post_covid2==1 & ( s`x'_r1==0 & s`x'_r2==.)
	replace cum_`x'=0 if post_covid2==1 & ( s`x'_r1==. & s`x'_r2==0)	
	replace cum_`x'=0 if baseline==1
}
label variable cum_activ_1 "Sell/transfer"
label variable cum_activ_2 "Online/remote"
label variable cum_activ_3 "Changed products/services"
label variable cum_activ_4 "Changed location"
label variable cum_activ_5 "Govt. help"
label variable cum_activ_6 "Formal/informal loan"


drop if post_covid==1 
 
 
*Define variables
local tabname				TableC11

local outcomes	     		has_business sales1_w5_hadb_all profit2_w5_hadb_all   
							
   
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
    foreach k in 2 5 6 {
    local controls1 		   	post_covid2 c.post_covid2#c.female     c.post_covid2#c.cum_activ_`k' c.post_covid2#c.female#c.cum_activ_`k'     i.County#c.post_covid2   c.cum_activ_`k'#i.County#c.post_covid2

local controls2 		`controls1'   i.sector_bl#c.post_covid2   i.sector_bl#c.cum_activ_`k'#c.post_covid2

	
	forvalues j=2/2 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
}

 
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)' "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) /// 
				stats(  N k meanb_0   meana_0 k meanb_1   meana_1, fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male"   "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female"     "Covid 2021 mean, female")) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitle ///
	keep(    c.post_covid2#c.female  *c.post_covid2#c.female#c.cum* ) 
	
		
	 

 *******************************************************************
**** TABLE C12 
*******************************************************************

/*Income activities 1 or zero*/

 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
drop if post_covid==1

bysort survey_id: egen wact=sum(number_work_act*baseline)

keep if wact<=1

bysort survey_id: egen wact_1=sum(number_work_act*post_covid2)

gen income_primact_k1=income_primact_kb if wact_1<=1


foreach var in income_primact_k1 {
winsor2 `var' , cuts(1 99) suffix(_w1bds)

gen `var'_w1=`var'_w1bds

drop `var'_w1bds 

winsor2 `var' , cuts(5 95) suffix(_w5bds)

gen `var'_w5=`var'_w5bds

drop `var'_w5bds 

gen ln_`var'=ln(`var'+1)
gen ihs_`var'=ln(`var' + sqrt((`var'*`var') + 1))
}
 
 

*Define variables
local tabname				TableC12

local outcomes	     	 income_primact_kb income_primact_kb_w5 income_primact_k1 income_primact_k1_w5 
							

 local controls1 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female        i.County#c.post_covid    i.County#c.post_covid2 i.sector_bl#c.post_covid i.sector_bl#c.post_covid2
 		
local controls2 		post_covid c.post_covid#c.female   	post_covid2 c.post_covid2#c.female         hours_total_children c.female#c.hours_total_children c.post_covid#c.hours_total_children c.post_covid#c.female#c.hours_total_children c.post_covid2#c.hours_total_children c.post_covid2#c.female#c.hours_total_children  i.County#c.post_covid    i.County#c.post_covid2 i.County#c.post_covid#c.hours_total_children    i.County#c.post_covid2#c.hours_total_children i.sector_bl#c.post_covid i.sector_bl#c.post_covid2 i.sector_bl#c.post_covid#c.hours_total_children i.sector_bl#c.post_covid2#c.hours_total_children    


 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			scalar meanb_`f' = r(mean)
			
			estadd scalar meanb_`f' = r(mean)
			
			
		}
			test c.post_covid#c.female==c.post_covid2#c.female  
		estadd scalar peq=r(p)
		
		estadd scalar pct=_b[c.post_covid2#c.female]/(meanb_0-meanb_1)
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
 


estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)' "Survey FE=post_covid2" "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(  N k meanb_0  meana_0 k meanb_1  meana_1   , fmt(%9.2gc %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels( "Observations" "\hline" "Pre-Covid mean, male"   "Covid 2021 mean, male" "\hline" "Pre-Covid mean, female"  "Covid 2021 mean, female"  )) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles  ///
	keep(c.post_covid2#c.female      ) ///
	order ( c.post_covid2#c.female    )  
	

********************************************************************
**** TABLE D1 
*******************************************************************

 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 

 
encode survey_id, gen (indid) 
xtset indid post_covid2 


*Define variables
local tabname				TableD1
 
local outcomes has_business  has_business_hadb has_business_nohadb 

local controls1 		  	 female i.County   i.sector_bl  grants_only  c.grants_only#c.female    grants_and_bds  c.grants_and_bds#c.female

 
 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
			reg `var' `controls`j'' l1.`var',  vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.`t' + c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0  
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 &  female==1 & grants_only==0 & grants_and_bds==0  
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test grants_only=grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		grants_only+ c.grants_only#c.female = ///
		grants_and_bds+ c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'

		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
}
  
  
 
 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 
keep if nbus_base==1
 

foreach x of varlist sales1_w5_hadb_all profit2_w5_hadb_all {
	gen miss_`x'=( `x'==. & baseline==1 & has_business==1)
	
	replace `x'=0 if miss_`x'==1 & baseline==1 
	
	bysort survey_id: egen mmiss_`x'=max(miss_`x')
	drop miss_`x'
	rename mmiss_`x' miss_`x'
}

 

encode survey_id, gen (indid) 
xtset indid post_covid2 

*Define variables
 

local outcomes	     		sales1_w5_hadb_all profit2_w5_hadb_all 
							

local controls1 		  	 female i.County   i.sector_bl  grants_only  c.grants_only#c.female    grants_and_bds  c.grants_and_bds#c.female
          
 
*Estimation 
 
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reg `var' `controls`j'' l1.`var' miss_`var',  vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.`t' + c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0 
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 &  female==1 & grants_only==0 & grants_and_bds==0 
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test grants_only=grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		grants_only+ c.grants_only#c.female = ///
		grants_and_bds+ c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'

		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

} 
										
 
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_onlyf grants_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "  "Grant and BDS effect for females" " " "\hline" "Control+BDS only mean, male" "Control +BDS only mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
				indicate("County=*County*" "Baseline business sector=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
		keep(   grants_only  grants_and_bds c.grants_only#c.female        c.grants_and_bds#c.female  ) ///
	order ( grants_only  c.grants_only#c.female   grants_and_bds c.grants_and_bds#c.female      ) 	 
	
********************************************************************
**** TABLE D2
*******************************************************************


 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 



*Define variables
local tabname				TableD2
 
local outcomes has_business  has_business_hadb has_business_nohadb 

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female c.post_covid2#c.bds_only c.post_covid2#c.bds_only#c.female

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  bds_only grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
}
  
  
 
 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 
keep if nbus_base==1


*Define variables
 

local outcomes	     		sales1_w5_hadb_all profit2_w5_hadb_all 
							

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female c.post_covid2#c.bds_only c.post_covid2#c.bds_only#c.female
          
 
*Estimation 
 
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only bds_only  grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

} 
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_onlyf grants_onlyfse bds_onlyf bds_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " " "BDS effect for females" " "   "Grant and BDS effect for females" " " "\hline" "Control mean, male" "Control mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
				indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep(  c.post_covid2#c.grants_only c.post_covid2#c.bds_only   c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_only#c.female c.post_covid2#c.bds_only#c.female        c.post_covid2#c.grants_and_bds#c.female  ) ///
	order ( c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female c.post_covid2#c.bds_only c.post_covid2#c.bds_only#c.female      c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female      )  
	
	
********************************************************************
**** TABLE D3
*******************************************************************

 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 
 

*Define variables
local tabname				TableD3

local outcomes	     		dnumber_sources_income number_sources_income income_primact_zb income_primact_zb_w5 income_primact_kb income_primact_kb_w5   gap gap_w5
 

local controls1 		  	 female i.County   i.sector_bl  grants_only  c.grants_only#c.female    grants_and_bds  c.grants_and_bds#c.female


foreach x of varlist dnumber_sources_income number_sources_income income_primact_zb income_primact_zb_w5 income_primact_kb income_primact_kb_w5   gap gap_w5 {
	gen miss_`x'=( `x'==. & baseline==1 & has_business==1)
	
	replace `x'=0 if miss_`x'==1 & baseline==1 
	
	bysort survey_id: egen mmiss_`x'=max(miss_`x')
	drop miss_`x'
	rename mmiss_`x' miss_`x'
}
encode survey_id, gen (indid) 
xtset indid post_covid2 


 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
			reg `var' `controls`j'' l1.`var' miss_`var',  vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.`t' + c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==0 & female==0 & grants_only==0 & grants_and_bds==0   
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==0 &  female==1 & grants_only==0 & grants_and_bds==0  
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test grants_only=grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		grants_only+ c.grants_only#c.female = ///
		grants_and_bds+ c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'

		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
  
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_onlyf grants_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "  "Grant and BDS effect for females" " " "\hline" "Control+BDS only mean, male" "Control +BDS only mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
				indicate("County=*County*" "Baseline business sector=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
		keep(   grants_only  grants_and_bds c.grants_only#c.female        c.grants_and_bds#c.female  ) ///
	order ( grants_only  c.grants_only#c.female   grants_and_bds c.grants_and_bds#c.female      ) 	
	
	
*******************************************************************
**** TABLE D4
*******************************************************************


 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 
 

*Define variables
local tabname				TableD4

local outcomes	     		dnumber_sources_income number_sources_income income_primact_zb income_primact_zb_w5 income_primact_kb income_primact_kb_w5   gap gap_w5
 

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female c.post_covid2#c.bds_only c.post_covid2#c.bds_only#c.female

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  bds_only grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
  
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_onlyf grants_onlyfse bds_onlyf bds_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " " "BDS effect for females" " "   "Grant and BDS effect for females" " " "\hline" "Control mean, male" "Control mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
				indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep(  c.post_covid2#c.grants_only c.post_covid2#c.bds_only   c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_only#c.female c.post_covid2#c.bds_only#c.female        c.post_covid2#c.grants_and_bds#c.female  ) ///
	order ( c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female c.post_covid2#c.bds_only c.post_covid2#c.bds_only#c.female      c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female      )  

*******************************************************************
**** TABLE D5
*****************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 
drop if post_covid==1 
 
encode survey_id, gen (indid) 
xtset indid post_covid2 

*Define variables
local tabname				TableD5
 
local outcomes   hours_total_children  hours_work  hours_dom hours_soc  hours_sleep hours_eat 

local controls1 		  	 female i.County   i.sector_bl  grants_only  c.grants_only#c.female    grants_and_bds  c.grants_and_bds#c.female

 
 

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
			reg `var' `controls`j'' l1.`var',  vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  grants_and_bds {
		
			lincom c.`t' + c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0  
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 &  female==1 & grants_only==0 & grants_and_bds==0  
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test grants_only=grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		grants_only+ c.grants_only#c.female = ///
		grants_and_bds+ c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'

		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
}

										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_onlyf grants_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "  "Grant and BDS effect for females" " " "\hline" "Control+BDS only mean, male" "Control +BDS only mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
				indicate("County=*County*" "Baseline business sector=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
		keep(   grants_only  grants_and_bds c.grants_only#c.female        c.grants_and_bds#c.female  ) ///
	order ( grants_only  c.grants_only#c.female   grants_and_bds c.grants_and_bds#c.female      ) 	
		 
*******************************************************************
**** TABLE D6
*****************************************************************

 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

drop if post_covid==1 

 
 
*Define variables
local tabname				TableD6

local outcomes	     		hours_total_children  hours_work  hours_dom hours_soc  hours_sleep hours_eat     
 

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female c.post_covid2#c.bds_only c.post_covid2#c.bds_only#c.female    c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		/*Het by gender*/
		foreach t in grants_only  bds_only grants_and_bds {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_only==0 & grants_and_bds==0 & bds_only==0
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		/*Grants vs. Grants and BDS by gender*/
		test c.post_covid2#c.grants_only=c.post_covid2#c.grants_and_bds
		local p=string(r(p),"%9.2f")
		estadd local pmale `p'
		
		
		test ///
		c.post_covid2#c.grants_only+ c.post_covid2#c.grants_only#c.female = ///
		c.post_covid2#c.grants_and_bds+ c.post_covid2#c.grants_and_bds#c.female
		local p=string(r(p),"%9.2f")
		estadd local pfemale `p'
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
  
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
			stats(N k grants_onlyf grants_onlyfse bds_onlyf bds_onlyfse  grants_and_bdsf grants_and_bdsfse k mmale mfemale k pmale pfemale , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " " "BDS effect for females" " "   "Grant and BDS effect for females" " " "\hline" "Control mean, male" "Control mean, female" "\hline"  "$[$ Grant=Grant and BDS $]$ male (p-value)" "$[$ Grant=Grant and BDS $]$ female (p-value)")) ///
				indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted  ///
	keep(  c.post_covid2#c.grants_only c.post_covid2#c.bds_only  c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_only#c.female c.post_covid2#c.bds_only#c.female        c.post_covid2#c.grants_and_bds#c.female  ) ///
	order ( c.post_covid2#c.grants_only c.post_covid2#c.grants_only#c.female   c.post_covid2#c.bds_only c.post_covid2#c.bds_only#c.female   c.post_covid2#c.grants_and_bds c.post_covid2#c.grants_and_bds#c.female      ) 	 
	
	
*******************************************************************
**** TABLE D7
*****************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

keep if post_covid2==1 



summ  avg_vignettes_cont   
replace avg_vignettes_cont   =(avg_vignettes_cont     -r(mean))/r(sd)

  			
*Define variables
local tabname				TableD7
 
local outcomes sect5_ladder_stepgc2 sect5_life_in5yearsgc2 sect5_wellbeinggc2  	sect5_workbalgc2 avg_vignettes_cont 

local controls1		  	 female i.County i.sector_bl grants_only c.grants_only#c.female    bds_only  c.bds_only#c.female   grants_and_bds  c.grants_and_bds#c.female
 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reg `var' `controls`j'' , vce(cluster survey_id)
		estadd ysumm
		
		 
		forvalues f=0/1 {
			sum `var' if  female==`f' & e(sample)==1 & post_covid2==1
			estadd scalar meana_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & post_covid==1
			estadd scalar mean_`f' = r(mean) 
			
			sum `var' if  female==`f' & e(sample)==1 & baseline==1
			estadd scalar meanb_`f' = r(mean)
			
		}
		
		foreach t in grants_only bds_only grants_and_bds {
		
			lincom `t' + c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		}
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

}
  
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
	b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
		indicate(`r(indicate_fe)'  "County FE=*County*" "Baseline business sector =*sector_bl*"  , label("\checkmark" "")  ) ///
				stats(N k grants_onlyf grants_onlyfse bds_onlyf bds_onlyfse grants_and_bdsf grants_and_bdsfse , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " " "BDS effect for females" " " "Grant and BDS effect for females" " " )) ///
	replace lines compress legend  depvar label   nonotes  noomitted nomtitles nonumbers ///
	keep(female grants_only    bds_only  grants_and_bds  c.grants_only#c.female    c.bds_only#c.female     c.grants_and_bds#c.female  ) ///
	order ( grants_only    c.grants_only#c.female   bds_only   c.bds_only#c.female     grants_and_bds  c.grants_and_bds#c.female  ) 	 
	
	
*******************************************************************
**** TABLE D8
*****************************************************************

use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 

bysort survey_id: egen spouse_had_b_baseline=sum((baseline==1)*(spouse_number_business>0))

label variable spouse_had_b_baseline  "Spouse had business at baseline"

drop if post_covid==1 

 

gen grants_all=(grants_only==1| grants_and_bds==1)
label variable grants_all "Grant"


*Define variables
local tabname				TableD8
 
local outcomes has_business  has_business_hadb has_business_nohadb 


local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_all c.post_covid2#c.grants_all#c.female     c.post_covid2#c.spouse_had_b_baseline c.post_covid2#c.female#c.spouse_had_b_baseline c.post_covid2#c.grants_all#c.spouse_had_b_baseline c.post_covid2#c.grants_all#c.spouse_had_b_baseline#c.female     

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		foreach t in grants_all {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		
		
		
		 
			
		*Grant effect for women with spouse entrepreneur
			lincom c.post_covid2#c.`t'+   c.post_covid2#c.`t'#c.female +c.post_covid2#c.`t'#c.spouse_had_b_baseline +c.post_covid2#c.`t'#c.female#c.spouse_had_b_baseline
			
		local `t'fb=string(r(estimate),"%9.2f")
			local `t'fbse=string(r(se),"%9.2f")
			estadd local `t'fbse (``t'fbse') 
			if r(p)<=0.01{
				estadd local `t'fb ``t'fb'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'fb ``t'fb'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'fb ``t'fb'*
			}
			else {
				estadd local `t'fb ``t'fb'
			}
		}
			
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
}
  
  
 
use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
bysort survey_id: egen spouse_had_b_baseline=sum((baseline==1)*(spouse_number_business>0))

label variable spouse_had_b_baseline  "Spouse had business at baseline"


drop if post_covid==1 
 
keep if nbus_base==1


gen grants_all=(grants_only==1| grants_and_bds==1)
label variable grants_all "Grant"



*Define variables
 

local outcomes	     		sales1_w5_hadb_all profit2_w5_hadb_all 
							

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_all c.post_covid2#c.grants_all#c.female     c.post_covid2#c.spouse_had_b_baseline c.post_covid2#c.female#c.spouse_had_b_baseline c.post_covid2#c.grants_all#c.spouse_had_b_baseline c.post_covid2#c.grants_all#c.spouse_had_b_baseline#c.female     

 
 
*Estimation 
 
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		foreach t in grants_all {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		
		
		 
			
		*Grant effect for women with spouse entrepreneur
			lincom c.post_covid2#c.`t'+   c.post_covid2#c.`t'#c.female +c.post_covid2#c.`t'#c.spouse_had_b_baseline +c.post_covid2#c.`t'#c.female#c.spouse_had_b_baseline
			
		local `t'fb=string(r(estimate),"%9.2f")
			local `t'fbse=string(r(se),"%9.2f")
			estadd local `t'fbse (``t'fbse') 
			if r(p)<=0.01{
				estadd local `t'fb ``t'fb'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'fb ``t'fb'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'fb ``t'fb'*
			}
			else {
				estadd local `t'fb ``t'fb'
			}
		}
			
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
	 
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

} 
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_allf grants_allfse grants_allfb grants_allfbse   k mmale mfemale   , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "  "Grant effect for females with entrepreneur spouse" " "  "\hline" "Control+BDS only mean, male" "Control+BDS only mean, female" )) ///
				indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep(  c.post_covid2#c.grants_all  c.post_covid2#c.grants_all#c.female        *grants_all*) ///
	order ( c.post_covid2#c.grants_all c.post_covid2#c.grants_all#c.female c.post_covid2#c.grants_all#c.spouse_had_b_baseline c.post_covid2#c.grants_all#c.spouse_had_b_baseline#c.female  )  

 
 *******************************************************************
**** TABLE D9
*****************************************************************

 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 
label variable savings_account  "Bank savings account at baseline"

drop if post_covid==1 

 

gen grants_all=(grants_only==1| grants_and_bds==1)
label variable grants_all "Grant"


*Define variables
local tabname				TableD9
 
local outcomes has_business  has_business_hadb has_business_nohadb 


local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_all c.post_covid2#c.grants_all#c.female     c.post_covid2#c.savings_account  c.post_covid2#c.female#c.savings_account c.post_covid2#c.grants_all#c.savings_account  c.post_covid2#c.grants_all#c.savings_account #c.female     

 
*Estimation 
local i = 1

est drop _all
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		foreach t in grants_all {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		
		
		
		 
			
		*Grant effect for women with savings account 
			lincom c.post_covid2#c.`t'+   c.post_covid2#c.`t'#c.female +c.post_covid2#c.`t'#c.savings_account  +c.post_covid2#c.`t'#c.female#c.savings_account 
			
		local `t'fb=string(r(estimate),"%9.2f")
			local `t'fbse=string(r(se),"%9.2f")
			estadd local `t'fbse (``t'fbse') 
			if r(p)<=0.01{
				estadd local `t'fb ``t'fb'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'fb ``t'fb'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'fb ``t'fb'*
			}
			else {
				estadd local `t'fb ``t'fb'
			}
		}
			
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
		
		
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
}
  
  
 
 use "$maindir/Data/GenderCovid_reg_dataset.dta", clear 
 

label variable savings_account   "Bank savings account at baseline"


drop if post_covid==1 

 
keep if nbus_base==1
 
 

gen grants_all=(grants_only==1| grants_and_bds==1)
label variable grants_all "Grant"



*Define variables
 

local outcomes	     		sales1_w5_hadb_all profit2_w5_hadb_all 
							

local controls1 		  	post_covid2 c.post_covid2#c.female i.County#c.post_covid2   i.sector_bl#c.post_covid2  c.post_covid2#c.grants_all c.post_covid2#c.grants_all#c.female     c.post_covid2#c.savings_account  c.post_covid2#c.female#c.savings_account c.post_covid2#c.grants_all#c.savings_account  c.post_covid2#c.grants_all#c.savings_account #c.female     

 
*Estimation 
 
 
foreach var in `outcomes'  {
	
	forvalues j=1/1 {
		reghdfe `var' `controls`j'' , absorb(survey_id) vce(cluster survey_id)
		estadd ysumm
		
		 
		foreach t in grants_all {
		
			lincom c.post_covid2#c.`t' + c.post_covid2#c.`t'#c.female
			
			local `t'f=string(r(estimate),"%9.2f")
			local `t'fse=string(r(se),"%9.2f")
			estadd local `t'fse (``t'fse') 
			if r(p)<=0.01{
				estadd local `t'f ``t'f'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'f ``t'f'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'f ``t'f'*
			}
			else {
				estadd local `t'f ``t'f'
			}
		
		
		 
			
		*Grant effect for women with spouse entrepreneur
		lincom c.post_covid2#c.`t'+   c.post_covid2#c.`t'#c.female +c.post_covid2#c.`t'#c.savings_account  +c.post_covid2#c.`t'#c.female#c.savings_account 
			
		local `t'fb=string(r(estimate),"%9.2f")
			local `t'fbse=string(r(se),"%9.2f")
			estadd local `t'fbse (``t'fbse') 
			if r(p)<=0.01{
				estadd local `t'fb ``t'fb'***
			}
			else if r(p)>0.01  & r(p)<=0.05{
				estadd local `t'fb ``t'fb'**
			}
			else if r(p)>0.05  & r(p)<=0.1{
				estadd local `t'fb ``t'fb'*
			}
			else {
				estadd local `t'fb ``t'fb'
			}
		}
			
		
		/*Control and BDS means*/
		summ `var' if e(sample)==1 & post_covid2==1 & female==0 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mmale `m'
		
		summ `var' if e(sample)==1 & post_covid2==1 & female==1 & grants_all==0  
		local m=string(r(mean),"%9.2f")
		estadd local mfemale `m'
		
	 
		est sto T_`tabname'_`i'
		local i = `i' + 1
	}
	
	

} 
										
estfe  *, labels(survey_id "Individual FE")
esttab * using "$output\\T_`tabname'.txt" 	 , ///
		b(%9.2fc) se(%9.2fc) star(* 0.10 ** 0.05 *** 0.01) ///
				stats(N k grants_allf grants_allfse grants_allfb grants_allfbse   k mmale mfemale   , fmt( %9.0gc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc %9.2fc) labels("Observations" "\hline" "Grant effect for females" " "  "Grant effect for females with bank savings account at baseline" " "  "\hline" "Control+BDS only mean, male" "Control+BDS only mean, female" )) ///
				indicate(`r(indicate_fe)' "Survey FE=post_covid2"  "County*Survey FE=*County*" "Baseline business sector*Survey FE=*sector_bl*"  , label("\checkmark" "")  ) ///
		replace lines compress legend  depvar label   nonotes  noomitted nomtitles ///
	keep(  c.post_covid2#c.grants_all  c.post_covid2#c.grants_all#c.female         *grants_all*) ///
	order ( c.post_covid2#c.grants_all c.post_covid2#c.grants_all#c.female c.post_covid2#c.grants_all#c.savings_account  c.post_covid2#c.grants_all#c.savings_account#c.female  ) 	 





